@@ -1,6 +1,3 @@
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import sys
 import os
 import shutil
@@ -14,43 +11,43 @@ import ct.apptools
 
 
 class TestVariant(unittest.TestCase):
-
     def setUp(self):
         uth.reset()
         self._tmpdir = None
 
     def test_extract_variant(self):
-        self.assertEqual(
-            "abc",
-            ct.configutils.extract_variant(
-                "--variant=abc".split()))
-        self.assertEqual(
-            "abc",
-            ct.configutils.extract_variant(
-                "--variant abc".split()))
+        self.assertEqual("abc", ct.configutils.extract_variant("--variant=abc".split()))
+        self.assertEqual("abc", ct.configutils.extract_variant("--variant abc".split()))
         self.assertEqual(
             "abc.123",
             ct.configutils.extract_variant(
-                "-a -b -x --blah --variant=abc.123 -a -b -z --blah".split()))
+                "-a -b -x --blah --variant=abc.123 -a -b -z --blah".split()
+            ),
+        )
         self.assertEqual(
             "abc.123",
             ct.configutils.extract_variant(
-                "-a -b -x --blah --variant abc.123 -a -b -cz--blah".split()))
+                "-a -b -x --blah --variant abc.123 -a -b -cz--blah".split()
+            ),
+        )
 
         # Note the -c overrides the --variant
         self.assertEqual(
             "blah",
             ct.configutils.extract_variant(
-                "-a -b -c blah.conf --variant abc.123 -a -b -cz--blah".split()))
+                "-a -b -c blah.conf --variant abc.123 -a -b -cz--blah".split()
+            ),
+        )
 
     def test_extract_variant_from_ct_conf(self):
         # Should find the one in the git repo ct.conf.d/ct.conf
         origdir = self._setup_and_chdir_temp_dir()
         variant = ct.configutils.extract_item_from_ct_conf(
-            key='variant',
-            user_config_dir='/var',
-            system_config_dir='/var',
-            exedir=uth.cakedir())
+            key="variant",
+            user_config_dir="/var",
+            system_config_dir="/var",
+            exedir=uth.cakedir(),
+        )
         self.assertEqual("debug", variant)
 
         # Cleanup
@@ -61,10 +58,11 @@ class TestVariant(unittest.TestCase):
         # Force to find the git repo ct.conf.d/ct.conf
         origdir = self._setup_and_chdir_temp_dir()
         variant = ct.configutils.extract_variant(
-            user_config_dir='/var',
-            system_config_dir='/var',
+            user_config_dir="/var",
+            system_config_dir="/var",
             exedir=uth.cakedir(),
-            verbose=0)
+            verbose=0,
+        )
         self.assertEqual("gcc.debug", variant)
 
         # Cleanup
@@ -72,7 +70,7 @@ class TestVariant(unittest.TestCase):
         shutil.rmtree(self._tmpdir, ignore_errors=True)
 
     def _setup_and_chdir_temp_dir(self):
-        ''' Returns the original working directory so you can chdir back to that at the end '''
+        """ Returns the original working directory so you can chdir back to that at the end """
         origdir = os.getcwd()
         self._tmpdir = tempfile.mkdtemp()
         os.chdir(self._tmpdir)
@@ -84,12 +82,19 @@ class TestVariant(unittest.TestCase):
         local_config_name = ct.unittesthelper.create_temp_config(self._tmpdir)
 
         configs = ct.configutils.defaultconfigs(
-            user_config_dir='/var',
-            system_config_dir='/var',
+            user_config_dir="/var",
+            system_config_dir="/var",
             exedir=uth.cakedir(),
-            verbose=0)
+            verbose=0,
+        )
 
-        self.assertListEqual([os.path.join(uth.ctconfdir(),'ct.conf'), os.path.join(self._tmpdir,'ct.conf')],configs)
+        self.assertListEqual(
+            [
+                os.path.join(uth.ctconfdir(), "ct.conf"),
+                os.path.join(self._tmpdir, "ct.conf"),
+            ],
+            configs,
+        )
 
         # Cleanup
         os.chdir(origdir)
@@ -98,24 +103,30 @@ class TestVariant(unittest.TestCase):
     def test_config_files_from_variant(self):
         origdir = self._setup_and_chdir_temp_dir()
         local_ct_conf = ct.unittesthelper.create_temp_ct_conf(self._tmpdir)
-        # Deliberately call the next config gcc.debug.conf to verify that 
+        # Deliberately call the next config gcc.debug.conf to verify that
         # the hierarchy of directories is working
-        local_config_name = ct.unittesthelper.create_temp_config(self._tmpdir,'gcc.debug.conf')
+        local_config_name = ct.unittesthelper.create_temp_config(
+            self._tmpdir, "gcc.debug.conf"
+        )
 
         configs = ct.configutils.config_files_from_variant(
-            variant='gcc.debug',
+            variant="gcc.debug",
             argv=[],
-            user_config_dir='/var',
-            system_config_dir='/var',
+            user_config_dir="/var",
+            system_config_dir="/var",
             exedir=uth.cakedir(),
-            verbose=0)
+            verbose=0,
+        )
 
-        self.assertListEqual([  os.path.join(uth.ctconfdir(),'ct.conf')
-                              , os.path.join(self._tmpdir,'ct.conf')
-                              , os.path.join(uth.ctconfdir(),'gcc.debug.conf')
-                              , os.path.join(self._tmpdir,'gcc.debug.conf')
-                              ]
-                            , configs)
+        self.assertListEqual(
+            [
+                os.path.join(uth.ctconfdir(), "ct.conf"),
+                os.path.join(self._tmpdir, "ct.conf"),
+                os.path.join(uth.ctconfdir(), "gcc.debug.conf"),
+                os.path.join(self._tmpdir, "gcc.debug.conf"),
+            ],
+            configs,
+        )
 
         # Cleanup
         os.chdir(origdir)
@@ -124,5 +135,6 @@ class TestVariant(unittest.TestCase):
     def tearDown(self):
         uth.reset()
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     unittest.main()
